pub struct Context<'k, 'v, K> {
pub(crate) key: &'k K,
pub(crate) value: &'v [u8],
}Expand description
Ed448 contexts as used by Ed448ph.
Contexts are domain separator strings that can be used to isolate uses of the algorithm between different protocols (which is very hard to reliably do otherwise) and between different uses within the same protocol.
To create a context, call either of the following:
Fields
key: &'k Kvalue: &'v [u8]Implementations